summaryrefslogtreecommitdiff
path: root/vcl/skia
diff options
context:
space:
mode:
Diffstat (limited to 'vcl/skia')
-rw-r--r--vcl/skia/SkiaHelper.cxx34
-rw-r--r--vcl/skia/skia_denylist_vulkan.xml (renamed from vcl/skia/skia_blacklist_vulkan.xml)4
-rw-r--r--vcl/skia/x11/gdiimpl.cxx2
3 files changed, 20 insertions, 20 deletions
diff --git a/vcl/skia/skia_blacklist_vulkan.xml b/vcl/skia/skia_denylist_vulkan.xml
index 5058012e9485..4c62ca4b04a9 100644
--- a/vcl/skia/skia_blacklist_vulkan.xml
+++ b/vcl/skia/skia_denylist_vulkan.xml
@@ -20,9 +20,9 @@
<root>
<whitelist>
</whitelist>
- <blacklist>
+ <denylist>
<entry os="all" vendor="intel" compare="less_equal" version="0.16.2">
<device id="all"/>
</entry>
- </blacklist>
+ </denylist>
</root>
diff --git a/vcl/skia/x11/gdiimpl.cxx b/vcl/skia/x11/gdiimpl.cxx
index 4754bfc64f95..72b1f9874c5c 100644
--- a/vcl/skia/x11/gdiimpl.cxx
+++ b/vcl/skia/x11/gdiimpl.cxx
@@ -74,7 +74,7 @@ X11SkiaSalGraphicsImpl::createWindowContext(Display* display, Drawable drawable,
// that the X11 visual is always the same. Ensure it is so.
static VisualID checkVisualID = -1U;
// Exception is for the temporary case during startup, when SkiaHelper's
- // checkDeviceBlacklisted() needs a WindowContext and may be called before SalVisual
+ // checkDeviceDenylisted() needs a WindowContext and may be called before SalVisual
// is ready.
if (!temporary)
{
diff --git a/vcl/skia/SkiaHelper.cxx b/vcl/skia/SkiaHelper.cxx
index 6b04c4300fe4..b7d45ad61196 100644
--- a/vcl/skia/SkiaHelper.cxx
+++ b/vcl/skia/SkiaHelper.cxx
@@ -45,12 +45,12 @@ bool isVCLSkiaEnabled() { return false; }
namespace SkiaHelper
{
-static OUString getBlacklistFile()
+static OUString getDenylistFile()
{
OUString url("$BRAND_BASE_DIR/" LIBO_SHARE_FOLDER);
rtl::Bootstrap::expandMacros(url);
- return url + "/skia/skia_blacklist_vulkan.xml";
+ return url + "/skia/skia_denylist_vulkan.xml";
}
static uint32_t driverVersion = 0;
@@ -90,7 +90,7 @@ static void writeToLog(SvStream& stream, const char* key, const OUString& value)
}
// Note that this function also logs system information about Vulkan.
-static bool isVulkanBlacklisted(const VkPhysicalDeviceProperties& props)
+static bool isVulkanDenylisted(const VkPhysicalDeviceProperties& props)
{
static const char* const types[]
= { "other", "integrated", "discrete", "virtual", "cpu", "??" }; // VkPhysicalDeviceType
@@ -125,10 +125,10 @@ static bool isVulkanBlacklisted(const VkPhysicalDeviceProperties& props)
<< ", vendor: " << vendorIdStr << " ("
<< vendorAsString(vendorId) << "), device: " << deviceIdStr
<< ", type: " << deviceType << ", name: " << props.deviceName);
- bool blacklisted = DriverBlocklist::IsDeviceBlocked(getBlacklistFile(), driverVersionString,
- vendorIdStr, deviceIdStr);
- writeToLog(logFile, "Blacklisted", blacklisted ? "yes" : "no");
- return blacklisted;
+ bool denylisted = DriverBlocklist::IsDeviceBlocked(getDenylistFile(), driverVersionString,
+ vendorIdStr, deviceIdStr);
+ writeToLog(logFile, "Denylisted", denylisted ? "yes" : "no");
+ return denylisted;
}
static void writeSkiaRasterInfo()
@@ -141,7 +141,7 @@ static void writeSkiaRasterInfo()
static sk_app::VulkanWindowContext::SharedGrContext getTemporaryGrContext();
-static void checkDeviceBlacklisted(bool blockDisable = false)
+static void checkDeviceDenylisted(bool blockDisable = false)
{
static bool done = false;
if (!done)
@@ -167,16 +167,16 @@ static void checkDeviceBlacklisted(bool blockDisable = false)
// the temporary context will clean up again.
grContext = getTemporaryGrContext();
}
- bool blacklisted = true; // assume the worst
+ bool denylisted = true; // assume the worst
if (grContext.getGrContext()) // Vulkan was initialized properly
{
- blacklisted = isVulkanBlacklisted(
+ denylisted = isVulkanDenylisted(
sk_app::VulkanWindowContext::getPhysDeviceProperties());
- SAL_INFO("vcl.skia", "Vulkan blacklisted: " << blacklisted);
+ SAL_INFO("vcl.skia", "Vulkan denylisted: " << denylisted);
}
else
SAL_INFO("vcl.skia", "Vulkan could not be initialized");
- if (blacklisted && !blockDisable)
+ if (denylisted && !blockDisable)
{
disableRenderMethod(RenderVulkan);
writeSkiaRasterInfo();
@@ -186,7 +186,7 @@ static void checkDeviceBlacklisted(bool blockDisable = false)
case RenderRaster:
SAL_INFO("vcl.skia", "Using Skia raster mode");
writeSkiaRasterInfo();
- return; // software, never blacklisted
+ return; // software, never denylisted
}
done = true;
}
@@ -226,7 +226,7 @@ bool isVCLSkiaEnabled()
/*
* There are a number of cases that these environment variables cover:
* * SAL_FORCESKIA forces Skia if disabled by UI options or blacklisted
* * SAL_DISABLESKIA avoids the use of Skia regardless of any option
*/
@@ -239,8 +239,8 @@ bool isVCLSkiaEnabled()
{
bRet = true;
SkGraphics::Init();
- // don't actually block if blacklisted, but log it if enabled, and also get the vendor id
- checkDeviceBlacklisted(true);
+ // don't actually block if denylisted, but log it if enabled, and also get the vendor id
+ checkDeviceDenylisted(true);
}
else if (getenv("SAL_FORCEGL"))
{
@@ -264,7 +264,7 @@ bool isVCLSkiaEnabled()
if (bEnable)
{
SkGraphics::Init();
- checkDeviceBlacklisted(); // switch to raster if driver is blacklisted
+ checkDeviceDenylisted(); // switch to raster if driver is denylisted
}
bRet = bEnable;
@@ -226,7 +226,7 @@ bool isVCLSkiaEnabled()
/*
* There are a number of cases that these environment variables cover:
- * * SAL_FORCESKIA forces Skia if disabled by UI options or blacklisted
+ * * SAL_FORCESKIA forces Skia if disabled by UI options or denylisted
* * SAL_DISABLESKIA avoids the use of Skia regardless of any option
*/